.. currentmodule:: uxarray

.. _examples:

Usage Examples
==============

Here's some examples of how to use the uxarray. We are always planning to add
more examples! If you are interested in contributing your own examples, please
see the :doc:`contributing`.

.. include:: notebook-examples.txt

.. toctree::
   :maxdepth: 1
   :hidden:

   examples/001-read-grid-data.ipynb
   examples/002-access-grid-info.ipynb
